.. currentmodule:: iniabu.main

============================
Initial Abundance Main Class
============================

:class:`IniAbu` Initial Abundance Class
---------------------------------------

.. autoclass:: IniAbu
    :members:
    :undoc-members:
